@@ -17,12 +17,12 @@
 void
 thread(unsigned id, void *prestate, void *state, struct mtt_result *tr)
 {
-	struct rpma_conn_cfg_common_prestate *pr =
-		(struct rpma_conn_cfg_common_prestate *)prestate;
+	struct rpma_conn_cfg_common_prestate *pr = (struct rpma_conn_cfg_common_prestate *)prestate;
 	int ret;
 	bool shared;
 
-	if ((ret = rpma_conn_cfg_get_compl_channel(pr->cfg_ptr, &shared))) {
+	ret = rpma_conn_cfg_get_compl_channel(pr->cfg_ptr, &shared);
+	if (ret) {
 		MTT_RPMA_ERR(tr, "rpma_conn_cfg_get_compl_channel", ret);
 		return;
 	}
