@@ -17,12 +17,12 @@
 void
 thread(unsigned id, void *prestate, void *state, struct mtt_result *tr)
 {
-	struct rpma_conn_cfg_common_prestate *pr =
-		(struct rpma_conn_cfg_common_prestate *)prestate;
+	struct rpma_conn_cfg_common_prestate *pr = (struct rpma_conn_cfg_common_prestate *)prestate;
 	uint32_t rcq_size;
 	int ret;
 
-	if ((ret = rpma_conn_cfg_get_rcq_size(pr->cfg_ptr, &rcq_size))) {
+	ret = rpma_conn_cfg_get_rcq_size(pr->cfg_ptr, &rcq_size);
+	if (ret) {
 		MTT_RPMA_ERR(tr, "rpma_conn_cfg_get_rcq_size", ret);
 		return;
 	}
