@@ -12,8 +12,7 @@
 #include "rpma_conn_cfg_common.h"
 
 /*
- * thread -- get connection configured sq size and check if its value is
- * as expected
+ * thread -- get connection configured sq size and check if its value is as expected
  */
 void
 thread(unsigned id, void *prestate, void *state, struct mtt_result *tr)
@@ -23,12 +22,12 @@ thread(unsigned id, void *prestate, void *state, struct mtt_result *tr)
 	uint32_t sq_size;
 	int ret;
 
-	if ((ret = rpma_conn_cfg_get_sq_size(pr->cfg_ptr, &sq_size))) {
+	ret = rpma_conn_cfg_get_sq_size(pr->cfg_ptr, &sq_size);
+	if (ret) {
 		MTT_RPMA_ERR(tr, "rpma_conn_cfg_get_sq_size", ret);
 		return;
 	}
 
 	if (sq_size != RPMA_CONN_CFG_COMMON_Q_SIZE_EXP)
-		MTT_ERR(tr, "sq_size != RPMA_CONN_CFG_COMMON_Q_SIZE_EXP",
-				EINVAL);
+		MTT_ERR(tr, "sq_size != RPMA_CONN_CFG_COMMON_Q_SIZE_EXP", EINVAL);
 }
