@@ -21,7 +21,8 @@ thread(unsigned id, void *prestate, void *state, struct mtt_result *tr)
 	int ret;
 	struct rpma_srq *srq;
 
-	if ((ret = rpma_conn_cfg_get_srq(pr->cfg_ptr, &srq))) {
+	ret = rpma_conn_cfg_get_srq(pr->cfg_ptr, &srq);
+	if (ret) {
 		MTT_RPMA_ERR(tr, "rpma_conn_cfg_get_srq", ret);
 		return;
 	}
