@@ -12,8 +12,7 @@
 #include "rpma_conn_cfg_common.h"
 
 /*
- * thread -- set connection establishment cq size and check if its value is
- * as expected
+ * thread -- set connection establishment cq size and check if its value is as expected
  */
 void
 thread(unsigned id, void *prestate, void *state, struct mtt_result *tr)
@@ -23,12 +22,14 @@ thread(unsigned id, void *prestate, void *state, struct mtt_result *tr)
 	uint32_t cq_size = 0;
 	int ret;
 
-	if ((ret = rpma_conn_cfg_set_cq_size(pr->cfg_ptr, RPMA_CONN_CFG_COMMON_Q_SIZE_EXP))) {
+	ret = rpma_conn_cfg_set_cq_size(pr->cfg_ptr, RPMA_CONN_CFG_COMMON_Q_SIZE_EXP);
+	if (ret) {
 		MTT_RPMA_ERR(tr, "rpma_conn_cfg_set_cq_size", ret);
 		return;
 	}
 
-	if ((ret = rpma_conn_cfg_get_cq_size(pr->cfg_ptr, &cq_size))) {
+	ret = rpma_conn_cfg_get_cq_size(pr->cfg_ptr, &cq_size);
+	if (ret) {
 		MTT_RPMA_ERR(tr, "rpma_conn_cfg_get_cq_size", ret);
 		return;
 	}
