@@ -12,23 +12,23 @@
 #include "rpma_conn_cfg_common.h"
 
 /*
- * thread -- set connection establishment rq size and check if its value is
- * as expected
+ * thread -- set connection establishment rq size and check if its value is as expected
  */
 void
 thread(unsigned id, void *prestate, void *state, struct mtt_result *tr)
 {
-	struct rpma_conn_cfg_common_prestate *pr =
-		(struct rpma_conn_cfg_common_prestate *)prestate;
+	struct rpma_conn_cfg_common_prestate *pr = (struct rpma_conn_cfg_common_prestate *)prestate;
 	uint32_t rq_size = 0;
 	int ret;
 
-	if ((ret = rpma_conn_cfg_set_rq_size(pr->cfg_ptr, RPMA_CONN_CFG_COMMON_Q_SIZE_EXP))) {
+	ret = rpma_conn_cfg_set_rq_size(pr->cfg_ptr, RPMA_CONN_CFG_COMMON_Q_SIZE_EXP);
+	if (ret) {
 		MTT_RPMA_ERR(tr, "rpma_conn_cfg_set_rq_size", ret);
 		return;
 	}
 
-	if ((ret = rpma_conn_cfg_get_rq_size(pr->cfg_ptr, &rq_size))) {
+	ret = rpma_conn_cfg_get_rq_size(pr->cfg_ptr, &rq_size);
+	if (ret) {
 		MTT_RPMA_ERR(tr, "rpma_conn_cfg_get_rq_size", ret);
 		return;
 	}
