@@ -21,7 +21,8 @@ thread(unsigned id, void *prestate, void *state, struct mtt_result *tr)
 	uint32_t rcq_size;
 	int ret;
 
-	if ((ret = rpma_srq_cfg_get_rcq_size(pr->cfg_ptr, &rcq_size))) {
+	ret = rpma_srq_cfg_get_rcq_size(pr->cfg_ptr, &rcq_size);
+	if (ret) {
 		MTT_RPMA_ERR(tr, "rpma_srq_cfg_get_rcq_size", ret);
 		return;
 	}
