@@ -1,6 +1,6 @@
 /* SPDX-License-Identifier: BSD-3-Clause */
 /* Copyright 2020, Intel Corporation */
-/* Copyright (c) 2022, Fujitsu Limited */
+/* Copyright (c) 2022-2023, Fujitsu Limited */
 
 /*
  * mocks-rpma-utils.h -- the rpma-utils mocks' header
@@ -13,5 +13,7 @@
 #define MOCK_ODP_INCAPABLE		0
 #define MOCK_ATOMIC_WRITE_CAPABLE	1
 #define MOCK_ATOMIC_WRITE_INCAPABLE	0
+#define MOCK_FLUSH_CAPABLE		1
+#define MOCK_FLUSH_INCAPABLE		0
 
 #endif /* MOCKS_RPMA_UTILS_H */
