@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: BSD-3-Clause
 /* Copyright 2022, Intel Corporation */
-/* Copyright (c) 2022, Fujitsu Limited */
+/* Copyright (c) 2022-2023, Fujitsu Limited */
 
 /*
  * mr-atomic_write.c -- rpma_mr_atomic_write() unit tests
@@ -20,32 +20,22 @@
 
 static const char Mock_src[8];
 
-#ifdef IBV_WR_ATOMIC_WRITE_SUPPORTED
+#ifdef NATIVE_ATOMIC_WRITE_SUPPORTED
 static struct ibv_wr_atomic_write_mock_args atomic_write_args;
+static struct ibv_qp_ex *qpxs[] = {NULL, MOCK_QPX};
+#else
+static struct ibv_qp_ex *qpxs[] = {NULL};
 #endif
+static int num_qpxs = sizeof(qpxs) / sizeof(qpxs[0]);
 static struct ibv_post_send_mock_args args;
 
 /*
- * configure_atomic_write -- configure common mock for rpma_mr_atomic_write()
+ * common_configure_mr_atomic_write -- common part of mocks for rpma_mr_atomic_write()
  */
 static void
-configure_mr_atomic_write(int flags, int ret)
+common_configure_mr_atomic_write(int flags, int ret)
 {
-	/* configure mock */
-#ifdef IBV_WR_ATOMIC_WRITE_SUPPORTED
-	expect_value(ibv_qp_to_qp_ex, qp, MOCK_QP);
-	will_return(ibv_qp_to_qp_ex, MOCK_QPX);
-	expect_value(ibv_wr_start_mock, qp, MOCK_QPX);
-	atomic_write_args.qp = MOCK_QPX;
-	atomic_write_args.wr_id = (uint64_t)MOCK_OP_CONTEXT;
-	atomic_write_args.wr_flags = (flags == RPMA_F_COMPLETION_ALWAYS) ? IBV_SEND_SIGNALED : 0;
-	atomic_write_args.rkey = MOCK_RKEY;
-	atomic_write_args.remote_addr = MOCK_RADDR + MOCK_DST_OFFSET;
-	atomic_write_args.atomic_wr = Mock_src;
-	will_return(ibv_wr_atomic_write_mock, &atomic_write_args);
-	expect_value(ibv_wr_complete_mock, qp, MOCK_QPX);
-	will_return(ibv_wr_complete_mock, ret);
-#else
+	/* configure mocks */
 	args.qp = MOCK_QP;
 	args.opcode = IBV_WR_RDMA_WRITE;
 	args.send_flags = IBV_SEND_INLINE | IBV_SEND_FENCE;
@@ -56,39 +46,35 @@ configure_mr_atomic_write(int flags, int ret)
 	args.rkey = MOCK_RKEY;
 	args.ret = ret;
 	will_return(ibv_post_send_mock, &args);
-#endif
 }
 
-#ifdef IBV_WR_ATOMIC_WRITE_SUPPORTED
 /*
- * atomic_write__qpx_NULL_success - rpma_mr_atomic_write
- * succeeded when ibv_qp_to_qp_ex() returned NULL
+ * configure_mr_atomic_write -- configure mocks for rpma_mr_atomic_write()
  */
 static void
-atomic_write__qpx_NULL_success(void **mrs_ptr)
+configure_mr_atomic_write(struct ibv_qp_ex *qpx, int flags, int ret)
 {
-	struct mrs *mrs = (struct mrs *)*mrs_ptr;
-
 	/* configure mocks */
+#ifdef NATIVE_ATOMIC_WRITE_SUPPORTED
 	expect_value(ibv_qp_to_qp_ex, qp, MOCK_QP);
-	will_return(ibv_qp_to_qp_ex, NULL);
-	args.qp = MOCK_QP;
-	args.opcode = IBV_WR_RDMA_WRITE;
-	args.send_flags = IBV_SEND_INLINE | IBV_SEND_FENCE | IBV_SEND_SIGNALED;
-	args.wr_id = (uint64_t)MOCK_OP_CONTEXT;
-	args.remote_addr = MOCK_RADDR + MOCK_DST_OFFSET;
-	args.rkey = MOCK_RKEY;
-	args.ret = MOCK_OK;
-	will_return(ibv_post_send_mock, &args);
-
-	/* run test */
-	int ret = rpma_mr_atomic_write(MOCK_QP, mrs->remote, MOCK_DST_OFFSET,
-			Mock_src, RPMA_F_COMPLETION_ALWAYS, MOCK_OP_CONTEXT);
-
-	/* verify the results */
-	assert_int_equal(ret, MOCK_OK);
-}
+	will_return(ibv_qp_to_qp_ex, qpx);
+	if (qpx && qpx->wr_atomic_write) {
+		expect_value(ibv_wr_start_mock, qp, MOCK_QPX);
+		atomic_write_args.qp = MOCK_QPX;
+		atomic_write_args.wr_id = (uint64_t)MOCK_OP_CONTEXT;
+		atomic_write_args.wr_flags = (flags == RPMA_F_COMPLETION_ALWAYS) ?
+				IBV_SEND_SIGNALED : 0;
+		atomic_write_args.rkey = MOCK_RKEY;
+		atomic_write_args.remote_addr = MOCK_RADDR + MOCK_DST_OFFSET;
+		atomic_write_args.atomic_wr = Mock_src;
+		will_return(ibv_wr_atomic_write_mock, &atomic_write_args);
+		expect_value(ibv_wr_complete_mock, qp, MOCK_QPX);
+		will_return(ibv_wr_complete_mock, ret);
+		return;
+	}
 #endif
+	common_configure_mr_atomic_write(flags, ret);
+}
 
 /*
  * atomic_write__COMPL_ON_ERROR_failed_E_PROVIDER -
@@ -100,15 +86,17 @@ atomic_write__COMPL_ON_ERROR_failed_E_PROVIDER(void **mrs_ptr)
 {
 	struct mrs *mrs = (struct mrs *)*mrs_ptr;
 
-	/* configure mocks */
-	configure_mr_atomic_write(RPMA_F_COMPLETION_ON_ERROR, MOCK_ERRNO);
+	for (int i = 0; i < num_qpxs; i++) {
+		/* configure mocks */
+		configure_mr_atomic_write(qpxs[i], RPMA_F_COMPLETION_ON_ERROR, MOCK_ERRNO);
 
-	/* run test */
-	int ret = rpma_mr_atomic_write(MOCK_QP, mrs->remote, MOCK_DST_OFFSET,
-			Mock_src, RPMA_F_COMPLETION_ON_ERROR, MOCK_OP_CONTEXT);
+		/* run test */
+		int ret = rpma_mr_atomic_write(MOCK_QP, mrs->remote, MOCK_DST_OFFSET,
+				Mock_src, RPMA_F_COMPLETION_ON_ERROR, MOCK_OP_CONTEXT);
 
-	/* verify the results */
-	assert_int_equal(ret, RPMA_E_PROVIDER);
+		/* verify the results */
+		assert_int_equal(ret, RPMA_E_PROVIDER);
+	}
 }
 
 /*
@@ -121,15 +109,17 @@ atomic_write__COMPL_ON_SUCCESS_failed_E_PROVIDER(void **mrs_ptr)
 {
 	struct mrs *mrs = (struct mrs *)*mrs_ptr;
 
-	/* configure mocks */
-	configure_mr_atomic_write(RPMA_F_COMPLETION_ALWAYS, MOCK_ERRNO);
+	for (int i = 0; i < num_qpxs; i++) {
+		/* configure mocks */
+		configure_mr_atomic_write(qpxs[i], RPMA_F_COMPLETION_ALWAYS, MOCK_ERRNO);
 
-	/* run test */
-	int ret = rpma_mr_atomic_write(MOCK_QP, mrs->remote, MOCK_DST_OFFSET,
-			Mock_src, RPMA_F_COMPLETION_ALWAYS, MOCK_OP_CONTEXT);
+		/* run test */
+		int ret = rpma_mr_atomic_write(MOCK_QP, mrs->remote, MOCK_DST_OFFSET,
+				Mock_src, RPMA_F_COMPLETION_ALWAYS, MOCK_OP_CONTEXT);
 
-	/* verify the results */
-	assert_int_equal(ret, RPMA_E_PROVIDER);
+		/* verify the results */
+		assert_int_equal(ret, RPMA_E_PROVIDER);
+	}
 }
 
 /*
@@ -140,15 +130,17 @@ atomic_write__COMPLETION_ALWAYS_success(void **mrs_ptr)
 {
 	struct mrs *mrs = (struct mrs *)*mrs_ptr;
 
-	/* configure mock */
-	configure_mr_atomic_write(RPMA_F_COMPLETION_ALWAYS, MOCK_OK);
+	for (int i = 0; i < num_qpxs; i++) {
+		/* configure mocks */
+		configure_mr_atomic_write(qpxs[i], RPMA_F_COMPLETION_ALWAYS, MOCK_OK);
 
-	/* run test */
-	int ret = rpma_mr_atomic_write(MOCK_QP, mrs->remote, MOCK_DST_OFFSET,
-			Mock_src, RPMA_F_COMPLETION_ALWAYS, MOCK_OP_CONTEXT);
+		/* run test */
+		int ret = rpma_mr_atomic_write(MOCK_QP, mrs->remote, MOCK_DST_OFFSET,
+				Mock_src, RPMA_F_COMPLETION_ALWAYS, MOCK_OP_CONTEXT);
 
-	/* verify the results */
-	assert_int_equal(ret, MOCK_OK);
+		/* verify the results */
+		assert_int_equal(ret, MOCK_OK);
+	}
 }
 
 /*
@@ -159,15 +151,17 @@ atomic_write__COMPLETION_ON_ERROR_success(void **mrs_ptr)
 {
 	struct mrs *mrs = (struct mrs *)*mrs_ptr;
 
-	/* configure mock */
-	configure_mr_atomic_write(RPMA_F_COMPLETION_ON_ERROR, MOCK_OK);
+	for (int i = 0; i < num_qpxs; i++) {
+		/* configure mocks */
+		configure_mr_atomic_write(qpxs[i], RPMA_F_COMPLETION_ON_ERROR, MOCK_OK);
 
-	/* run test */
-	int ret = rpma_mr_atomic_write(MOCK_QP, mrs->remote, MOCK_DST_OFFSET,
-			Mock_src, RPMA_F_COMPLETION_ON_ERROR, MOCK_OP_CONTEXT);
+		/* run test */
+		int ret = rpma_mr_atomic_write(MOCK_QP, mrs->remote, MOCK_DST_OFFSET,
+				Mock_src, RPMA_F_COMPLETION_ON_ERROR, MOCK_OP_CONTEXT);
 
-	/* verify the results */
-	assert_int_equal(ret, MOCK_OK);
+		/* verify the results */
+		assert_int_equal(ret, MOCK_OK);
+	}
 }
 
 /*
@@ -177,7 +171,7 @@ static int
 group_setup_mr_atomic_write(void **unused)
 {
 	/* configure global mocks */
-#ifdef IBV_WR_ATOMIC_WRITE_SUPPORTED
+#ifdef NATIVE_ATOMIC_WRITE_SUPPORTED
 	/*
 	 * ibv_wr_start(), ibv_wr_atomic_write() and ibv_wr_complete() are defined
 	 * as static inline functions in the included header <infiniband/verbs.h>,
@@ -215,12 +209,6 @@ group_setup_mr_atomic_write(void **unused)
 
 static const struct CMUnitTest tests_mr__atomic_write[] = {
 	/* rpma_mr_atomic_write() unit tests */
-#ifdef IBV_WR_ATOMIC_WRITE_SUPPORTED
-	cmocka_unit_test_setup_teardown(
-			atomic_write__qpx_NULL_success,
-			setup__mr_local_and_remote,
-			teardown__mr_local_and_remote),
-#endif
 	cmocka_unit_test_setup_teardown(
 			atomic_write__COMPL_ON_ERROR_failed_E_PROVIDER,
 			setup__mr_local_and_remote,
