@@ -2,6 +2,7 @@
 #
 # SPDX-License-Identifier: BSD-3-Clause
 # Copyright 2016-2023, Intel Corporation
+# Copyright (c) 2023 Fujitsu Limited
 #
 
 #
@@ -193,6 +194,66 @@ sudo_password make uninstall
 cd $WORKDIR
 rm -rf $WORKDIR/build
 
+echo
+echo "#####################################################################"
+echo "### Verify build with BUILD_FORCE_ODP_NOT_SUPPORTED=ON ($CC, DEBUG)"
+echo "#####################################################################"
+
+mkdir -p $WORKDIR/build
+cd $WORKDIR/build
+
+CC=$CC \
+$CMAKE .. -DCMAKE_BUILD_TYPE=Debug \
+	-DTEST_DIR=$TEST_DIR \
+	-DBUILD_DEVELOPER_MODE=1 \
+	-DBUILD_FORCE_ODP_NOT_SUPPORTED=ON
+
+make -j$(nproc) || make
+ctest --output-on-failure
+
+cd $WORKDIR
+rm -rf $WORKDIR/build
+
+echo
+echo "#########################################################################################"
+echo "### Verify build with BUILD_FORCE_NATIVE_ATOMIC_WRITE_NOT_SUPPORTED=ON ($CC, DEBUG)"
+echo "#########################################################################################"
+
+mkdir -p $WORKDIR/build
+cd $WORKDIR/build
+
+CC=$CC \
+$CMAKE .. -DCMAKE_BUILD_TYPE=Debug \
+	-DTEST_DIR=$TEST_DIR \
+	-DBUILD_DEVELOPER_MODE=1 \
+	-DBUILD_FORCE_NATIVE_ATOMIC_WRITE_NOT_SUPPORTED=ON
+
+make -j$(nproc) || make
+ctest --output-on-failure
+
+cd $WORKDIR
+rm -rf $WORKDIR/build
+
+echo
+echo "#########################################################################################"
+echo "### Verify build with BUILD_FORCE_NATIVE_FLUSH_NOT_SUPPORTED=ON ($CC, DEBUG)"
+echo "#########################################################################################"
+
+mkdir -p $WORKDIR/build
+cd $WORKDIR/build
+
+CC=$CC \
+$CMAKE .. -DCMAKE_BUILD_TYPE=Debug \
+	-DTEST_DIR=$TEST_DIR \
+	-DBUILD_DEVELOPER_MODE=1 \
+	-DBUILD_FORCE_NATIVE_FLUSH_NOT_SUPPORTED=ON
+
+make -j$(nproc) || make
+ctest --output-on-failure
+
+cd $WORKDIR
+rm -rf $WORKDIR/build
+
 echo
 echo "##################################################################"
 echo "### Verify build and install (in dir: ${PREFIX}) ($CC, RELEASE)"
@@ -211,7 +272,19 @@ $CMAKE .. -DCMAKE_BUILD_TYPE=Release \
 make -j$(nproc)
 ctest --output-on-failure
 
-if [ "$PACKAGE_MANAGER" = "" ]; then
+# check if librpma uses rdma-core installed from sources
+RDMA_CORE_PATH="/rdma-core/build/lib"
+if ldd src/librpma.so | grep -q -e "$RDMA_CORE_PATH"; then
+	RPMA_USES_RDMA_CORE_FROM_SOURCES=YES
+else
+	RPMA_USES_RDMA_CORE_FROM_SOURCES=NO
+fi
+
+# If there is no supported package manager or
+# if librpma uses rdma-core installed from sources
+# install the librpma library from sources too,
+# otherwise make the librpma package and install it.
+if [ "$PACKAGE_MANAGER" = "" -o "$RPMA_USES_RDMA_CORE_FROM_SOURCES" = "YES" ]; then
 	# install the library from sources
 	sudo_password make -j$(nproc) install
 else
@@ -224,32 +297,25 @@ else
 
 	make -j$(nproc) package
 	find . -iname "librpma*.$PACKAGE_MANAGER"
-fi
 
-if [ $PACKAGE_MANAGER = "deb" ]; then
-	echo "$ dpkg-deb --info ./librpma*.deb"
-	dpkg-deb --info ./librpma*.deb
-
-	echo "$ dpkg-deb -c ./librpma*.deb"
-	dpkg-deb -c ./librpma*.deb
-
-	echo "$ sudo -S dpkg -i ./librpma*.deb"
-	echo $USERPASS | sudo -S dpkg -i ./librpma*.deb
-
-elif [ $PACKAGE_MANAGER = "rpm" ]; then
-	echo "$ rpm -q --info ./librpma*.rpm"
-	rpm -q --info ./librpma*.rpm && true
-
-	echo "$ rpm -q --list ./librpma*.rpm"
-	rpm -q --list ./librpma*.rpm && true
-
-	echo "$ sudo -S rpm -ivh --force *.rpm"
-	echo $USERPASS | sudo -S rpm -ivh --force *.rpm
+	if [ $PACKAGE_MANAGER = "deb" ]; then
+		set -x
+		dpkg-deb --info ./librpma*.deb || true
+		dpkg-deb -c ./librpma*.deb || true
+		sudo_password dpkg -i ./librpma*.deb
+		set +x
+	elif [ $PACKAGE_MANAGER = "rpm" ]; then
+		set -x
+		rpm -q --info ./librpma*.rpm || true
+		rpm -q --list ./librpma*.rpm || true
+		sudo_password rpm -ivh --force *.rpm
+		set +x
+	fi
 fi
 
 test_compile_all_examples_standalone
 
-if [ "$PACKAGE_MANAGER" = "" ]; then
+if [ "$PACKAGE_MANAGER" = "" -o "$RPMA_USES_RDMA_CORE_FROM_SOURCES" = "YES" ]; then
 	# uninstall the library, since it was installed from sources
 	cd $WORKDIR/build
 	sudo_password make uninstall
